@@ -7,8 +7,6 @@
 
 #pragma once
 
-#include "kpimtextedit_export.h"
-
 #include <KActionMenu>
 
 namespace KPIMTextEdit
@@ -21,7 +19,7 @@ public:
     ~EmoticonTextEditAction() override;
 
 Q_SIGNALS:
-    void emoticonActivated(const QString &);
+    void insertEmoticon(const QString &);
 
 private:
     class EmoticonTextEditActionPrivate;
