@@ -8,8 +8,7 @@
 
 #include <QTabWidget>
 
-#include "emoticonunicodeutils.h"
-#include "kpimtextedit_export.h"
+#include "kpimtextedit_private_export.h"
 
 namespace KPIMTextEdit
 {
@@ -19,7 +18,7 @@ class EmoticonRecentUsedFilterProxyModel;
  * @brief The EmoticonUnicodeTab class
  * @author Laurent Montel <montel@kde.org>
  */
-class KPIMTEXTEDIT_EXPORT EmoticonUnicodeTab : public QTabWidget
+class KPIMTEXTEDIT_TESTS_EXPORT EmoticonUnicodeTab : public QTabWidget
 {
     Q_OBJECT
 public:
@@ -30,14 +29,13 @@ public:
 
     void searchUnicode(const QString &str);
 Q_SIGNALS:
-    void itemSelected(const QString &);
+    void itemSelected(const QString &str);
 
 private:
-    void createEmoticonTab(const QString &str, const QVector<EmoticonUnicodeUtils::EmoticonStruct> &emoticons);
-    void createSearchTab();
-    void createRecentTab();
-    void slotInsertEmoticons(const QString &identifier);
-    void slotUsedIdentifierChanged(const QStringList &lst);
+    KPIMTEXTEDIT_NO_EXPORT void createSearchTab();
+    KPIMTEXTEDIT_NO_EXPORT void createRecentTab();
+    KPIMTEXTEDIT_NO_EXPORT void slotInsertEmoticons(const QString &str, const QString &identifier);
+    KPIMTEXTEDIT_NO_EXPORT void slotUsedIdentifierChanged(const QStringList &lst);
     EmoticonUnicodeProxyModel *const mEmoticonUnicodeSearchProxyModel;
     EmoticonRecentUsedFilterProxyModel *const mEmoticonUnicodeRecentProxyModel;
     int mSearchTabIndex = -1;
