@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -21,6 +21,7 @@ using namespace KPIMTextEdit;
 
 InsertHtmlEditor::InsertHtmlEditor(QWidget *parent)
     : KPIMTextEdit::PlainTextEditor(parent)
+    , mTextEditorCompleter(new KPIMTextEdit::TextEditorCompleter(this, this))
 {
     const KSyntaxHighlighting::Definition def = mRepo.definitionForName(QStringLiteral("HTML"));
     if (!def.isValid()) {
@@ -32,16 +33,13 @@ InsertHtmlEditor::InsertHtmlEditor(QWidget *parent)
                                                                      : mRepo.defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
     hl->setDefinition(def);
     setFocus();
-    mTextEditorCompleter = new KPIMTextEdit::TextEditorCompleter(this, this);
     const QStringList completerList = {QStringLiteral("<b></b>"), QStringLiteral("<i></i>"), QStringLiteral("<u></u>")};
     // Add more
     mTextEditorCompleter->setCompleterStringList(completerList);
     mTextEditorCompleter->setExcludeOfCharacters(QStringLiteral("~!@#$%^&*()+{}|,./;'[]\\-= "));
 }
 
-InsertHtmlEditor::~InsertHtmlEditor()
-{
-}
+InsertHtmlEditor::~InsertHtmlEditor() = default;
 
 void InsertHtmlEditor::keyPressEvent(QKeyEvent *e)
 {
