@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -38,11 +38,9 @@ protected:
 public Q_SLOTS:
     void slotBlockCountChanged(int numberBlockCount);
 
-private Q_SLOTS:
-    void slotCloseBar();
-    void slotGoToLine();
-
 private:
+    KPIMTEXTEDIT_NO_EXPORT void slotCloseBar();
+    KPIMTEXTEDIT_NO_EXPORT void slotGoToLine();
     std::unique_ptr<TextGoToLineWidgetPrivate> const d;
 };
 }
