@@ -28,6 +28,9 @@
 #ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
 #include <TextEditTextToSpeech/TextToSpeech>
 #endif
+#ifdef HAVE_KTEXTADDONS_TEXT_EMOTICONS_SUPPORT
+#include <TextEmoticonsWidgets/EmoticonTextEditAction>
+#endif
 
 #include <KColorScheme>
 #include <QApplication>
@@ -282,12 +285,25 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
             d->webshortcutMenuManager->setSelectedText(selectedText);
             d->webshortcutMenuManager->addWebShortcutsToMenu(popup);
         }
+#ifdef HAVE_KTEXTADDONS_TEXT_EMOTICONS_SUPPORT
+        if (emojiSupport()) {
+            popup->addSeparator();
+            auto action = new TextEmoticonsWidgets::EmoticonTextEditAction(this);
+            popup->addAction(action);
+            connect(action, &TextEmoticonsWidgets::EmoticonTextEditAction::insertEmoticon, this, &RichTextEditor::slotInsertEmoticon);
+        }
+#endif
         addExtraMenuEntry(popup, pos);
         return popup;
     }
     return nullptr;
 }
 
+void RichTextEditor::slotInsertEmoticon(const QString &str)
+{
+    insertPlainText(str);
+}
+
 void RichTextEditor::slotSpeakText()
 {
     QString text;
@@ -313,6 +329,20 @@ bool RichTextEditor::webShortcutSupport() const
     return d->supportFeatures & AllowWebShortcut;
 }
 
+void RichTextEditor::setEmojiSupport(bool b)
+{
+    if (b) {
+        d->supportFeatures |= Emoji;
+    } else {
+        d->supportFeatures = (d->supportFeatures & ~Emoji);
+    }
+}
+
+bool RichTextEditor::emojiSupport() const
+{
+    return d->supportFeatures & Emoji;
+}
+
 void RichTextEditor::addIgnoreWords(const QStringList &lst)
 {
     d->ignoreSpellCheckingWords = lst;
@@ -601,6 +631,7 @@ void RichTextEditor::addIgnoreWordsToHighLighter()
 
 void RichTextEditor::setHighlighter(Sonnet::Highlighter *_highLighter)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Sonnet::SpellCheckDecorator *decorator = createSpellCheckDecorator();
     delete decorator->highlighter();
     decorator->setHighlighter(_highLighter);
@@ -610,6 +641,10 @@ void RichTextEditor::setHighlighter(Sonnet::Highlighter *_highLighter)
     _highLighter->setParent(decorator);
     d->richTextDecorator = decorator;
     addIgnoreWordsToHighLighter();
+#else
+#pragma "NEED TO FIX IN QT6"
+
+#endif
 }
 
 void RichTextEditor::focusInEvent(QFocusEvent *event)
